# frozen_string_literal: true

require 'thor'

module Sftui
  # Handle the application command line parsing
  # and the dispatch to various command objects
  #
  # @api public
  class CLI < Thor
    # Error raised by this runner
    Error = Class.new(StandardError)

    desc 'version', 'sftui version'
    def version
      require_relative 'version'
      puts "v#{Sftui::VERSION}"
    end
    map %w(--version -v) => :version

    desc 'stream UART', 'Command description...'
    method_option :help, aliases: '-h', type: :boolean,
                         desc: 'Display usage information'
    def stream(uart)
      if options[:help]
        invoke :help, ['stream']
      else
        require_relative 'commands/stream'
        Sftui::Commands::Stream.new(uart, options).execute
      end
    end
  end
end
